yalchemy
########################################################################

Documentation
=============

`View the yalchemy docs here <http://yalchemy.readthedocs.io/>`_.

Installation
============

yalchemy can be installed with::

    pip3 install yalchemy


Primary Authors
===============

* Wes Kendall <wesleykendall@gmail.com>
* Chris Hartfield <chris.hartfield@cloverhealth.com>

Other contributors can be found in the AUTHORS file

Contributing Guide
==================

For information on setting up yalchemy for development and contributing changes, view `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.
